@@ -12,3 +12,10 @@ class ChangeThemeAction(BaseAction):
 @dataclass
 class EditorScreenReadyAction(BaseAction):
     type = "EDITOR_SCREEN_READY_ACTION"
+
+
+@dataclass
+class ChangeAppTitleAction(BaseAction):
+    type = "CHANGE_APP_TITLE_ACTION"
+    title: str
+    sub_title: str
