@@ -38,14 +38,27 @@ def init_state(state: AppState, data: JsonLoadResult) -> None:
         for quiz in data.quizes
         for question in quiz.questions
     }
-    state.current.app_title = "Клондайк аналитика"
-    state.current.app_subtitle = "Интерактивный тренажер Python на вашем " +\
-        f"компьютере (version. {analyst_klondike.__version__})"
+    state.current.app_title = _get_title(state)
+    state.current.app_subtitle = _get_subtitle()
     state.current.app_version = analyst_klondike.__version__
     state.current.opened_file_min_supported_app_version = \
         data.quiz_info.min_supported_app_version
 
 
+def _get_title(state: AppState) -> str:
+    title = "Клондайк аналитика"
+    if state.is_teacher_mode:
+        title += " (teacher mode)"
+    if state.event_sender == "no_events":
+        title += " no events"
+    return title
+
+
+def _get_subtitle() -> str:
+    return "Интерактивный тренажер Python на вашем " +\
+        f"компьютере (version. {analyst_klondike.__version__})"
+
+
 def init_file_and_app_version(state: AppState, data: JsonLoadResult) -> None:
     state.current.app_version = analyst_klondike.__version__
     state.current.opened_file_min_supported_app_version = \
