@@ -16,7 +16,11 @@ from textual.binding import Binding
 # message box
 from analyst_klondike.features.app.open_file_action import open_file
 from analyst_klondike.features.code.selector import has_failed_cases
-from analyst_klondike.features.data_context.data_state import PythonTaskState
+from analyst_klondike.features.code_import.ui_actions.import_task_from_code import (
+    import_task_action
+)
+from analyst_klondike.features.code_import.ui_actions.selectors import select_is_in_teacher_mode
+from analyst_klondike.features.data_context.data_state import PythonQuizState, PythonTaskState
 from analyst_klondike.features.events.event_hook import send_event
 from analyst_klondike.features.message_box.ui.mb_screen import MessageBoxScreen
 
@@ -30,7 +34,11 @@ from analyst_klondike.state.app_state import (
     select)
 
 # selectors
-from analyst_klondike.features.current.selectors import select_current_task, select_has_file_openned
+from analyst_klondike.features.current.selectors import (
+    select_current_quiz,
+    select_current_task,
+    select_has_file_openned
+)
 
 # actions
 from analyst_klondike.features.app.actions import EditorScreenReadyAction
@@ -94,13 +102,22 @@ class EditorScreen(Screen[Any]):
                                    description="Справка",
                                    tooltip="Отобразить справку")
 
+    import_tasks_binding = Binding(
+        id="import_tasks_from_code",
+        key="f2",
+        action="import_tasks_from_code",
+        description="Импортировать задачи",
+        tooltip="Создать новый файл с задачами и поместить его в текущий каталог"
+    )
+
     MSG_BOX_SCREEN_ID = "message_box_screen"
 
     BINDINGS = [
         display_help_binding,
         open_file_binding,
         save_file_binding,
-        run_code_binding
+        run_code_binding,
+        import_tasks_binding
     ]
 
     class UpdateAppTitleMessage(Message):
@@ -160,6 +177,8 @@ class EditorScreen(Screen[Any]):
             pass
 
         self._display_message_box(new_state)
+        # refresh visibility/enable status for footer buttons
+        self.refresh_bindings()
 
     def _display_message_box(self, state: AppState) -> None:
         current_screen_id = self.app.screen_stack[-1].id
@@ -245,11 +264,31 @@ class EditorScreen(Screen[Any]):
     def action_display_help(self) -> None:
         app_dispatch(DisplayMessageBoxAction(_WELLCOME_MESSAGE))
 
+    def action_import_tasks_from_code(self) -> None:
+        curr_quiz = select(select_current_quiz)
+
+        def _on_file_selected(file_path: str | None) -> None:
+            if file_path is None:
+                return
+            if curr_quiz is None:
+                self.app.notify(
+                    "Необходимо выбрать тест для импортирования",
+                    title="Импортирование",
+                    severity="error",
+                    timeout=1
+                )
+            assert isinstance(curr_quiz, PythonQuizState)
+            import_task_action(curr_quiz.id, file_path)
+        if curr_quiz is not None:
+            self.app.push_screen(OpenFileScreen(), _on_file_selected)
+        else:
+            app_dispatch(DisplayMessageBoxAction(
+                message="Необходимо выбрать тест куда импортировать задачи"))
+
     def check_action(self, action: str, parameters: tuple[object, ...]):
         if action == EditorScreen.run_code_binding.action:
-            has_file = select(select_has_file_openned)
-            # Кнопка должна быть активна, если задача активирована
-            if has_file:
+            curr_task = select(select_current_task)
+            if curr_task is not None:
                 return True
             return None
         if action == EditorScreen.save_file_binding.action:
@@ -257,6 +296,14 @@ class EditorScreen(Screen[Any]):
             if has_file:
                 return True
             return None
+        if action == EditorScreen.import_tasks_binding.action:
+            is_teacher_mode = select(select_is_in_teacher_mode)
+            if not is_teacher_mode:
+                return False
+            curr_quiz = select(select_current_quiz)
+            if curr_quiz is not None:
+                return True
+            return None
         return True
 
     @staticmethod
