@@ -2,7 +2,7 @@ from typing import Literal
 from textual import on
 from textual.app import ComposeResult
 from textual.screen import ModalScreen
-from textual.containers import Grid
+from textual.containers import Vertical, Horizontal, Container
 from textual.widgets import Label, Button
 
 SaveOrExitModalResult = Literal["save", "not_save", "cancel"]
@@ -13,9 +13,10 @@ class SaveOnExitModal(ModalScreen[SaveOrExitModalResult]):
     CSS_PATH = "save_on_exit_modal.tcss"
 
     def compose(self) -> ComposeResult:
-        with Grid(id="dialog"):
+        yield Container(id="shadow")
+        with Vertical(id="dialog"):
             yield Label("Сохранить файл?")
-            with Grid(id="buttons"):
+            with Horizontal(id="buttons"):
                 yield Button(id="save", label="Сохранить", variant="success")
                 yield Button(id="not_save", label="Не сохранять", variant="error")
                 yield Button(id="cancel", label="Отмена", variant="default")
