@@ -1,4 +1,4 @@
-from typing import Any
+from typing import Any, Callable
 from textual import on
 from textual.app import App
 import pyperclip
@@ -24,6 +24,7 @@ class RunnerApp(App[Any]):
 
     def __init__(self) -> None:
         super().__init__()
+        self.on_mounted_callback: Callable[[], None] | None = None
 
     def update_view(self, state: AppState) -> None:
         RunnerApp.EDITOR_SCREEN.update_view(state)
@@ -33,6 +34,8 @@ class RunnerApp(App[Any]):
         self.theme = "gruvbox"
         self.title = "Клондайк аналитика"
         self.sub_title = "Интерактивный тренажер Python на вашем компьютере"
+        if self.on_mounted_callback is not None:
+            self.on_mounted_callback()
 
     @on(EditorScreen.UpdateAppTitleMessage)
     def on_title_subtitle_changed(self, event: EditorScreen.UpdateAppTitleMessage) -> None:
